@@ -1,5 +1,5 @@
 import warnings
-from .constants import mad_dict
+from .constants import MAD_CONFORM
 
 
 def _inform_(df, high_Z, conf):
@@ -46,7 +46,7 @@ def _report_mad_(digs, MAD):
     """
     print(f'Mean Absolute Deviation: {MAD:.6f}')
     if digs != -2:
-        mads = mad_dict[digs]
+        mads = MAD_CONFORM[digs]
         if MAD <= mads[0]:
             print(f'MAD <= {mads[0]:.6f}: Close conformity.\n')
         elif MAD <= mads[1]:
@@ -70,13 +70,13 @@ def _report_KS_(KS, crit_KS):
           f"\n\tCritical value: {crit_KS:.6f} -- {result}")
 
 
-def _report_chi2_(chi2, crit_chi2):
+def _report_chi2_(chi2, CRIT_CHI2):
     """Reports the test Chi-square statistic and compares it to critical values,
     depending on the confidence level
     """
-    result = 'PASS' if chi2 <= crit_chi2 else 'FAIL'
+    result = 'PASS' if chi2 <= CRIT_CHI2 else 'FAIL'
     print(f"\n\tChi square: {chi2:.6f}",
-          f"\n\tCritical value: {crit_chi2:.6f} -- {result}")
+          f"\n\tCritical value: {CRIT_CHI2:.6f} -- {result}")
 
 
 def _report_Z_(df, high_Z, crit_Z):
@@ -100,6 +100,24 @@ def _report_summ_(test, high_diff):
         print(test.sort_values('AbsDif', ascending=False))
 
 
+def _report_bhattac_coeff_(bhattac_coeff):
+    """
+    """
+    print(f"Bhattacharyya Coefficient: {bhattac_coeff:6f}\n")
+
+
+def _report_bhattac_dist_(bhattac_dist):
+    """
+    """
+    print(f"Bhattacharyya Distance: {bhattac_dist:6f}\n")
+
+
+def _report_kl_diverg_(kl_diverg):
+    """
+    """
+    print(f"Kullback-Leibler Divergence: {kl_diverg:6f}\n")
+
+
 def _report_test_(test, high=None, crit_vals=None):
     """Main report function. Receives the Args: to report with, initiates
     the process, and calls the right reporting helper function(s), depending
@@ -108,6 +126,9 @@ def _report_test_(test, high=None, crit_vals=None):
     print('\n', f'  {test.name}  '.center(50, '#'), '\n')
     if not 'Summation' in test.name:
         _report_mad_(test.digs, test.MAD)
+        _report_bhattac_coeff_(test.bhattacharyya_coefficient)
+        _report_bhattac_dist_(test.bhattacharyya_distance)
+        _report_kl_diverg_(test.kullback_leibler_divergence)
         if test.confidence is not None:
             print(f"For confidence level {test.confidence}%: ")
             _report_KS_(test.KS, crit_vals['KS'])
