@@ -1,5 +1,5 @@
-from numpy import sqrt
-from .constants import crit_chi2, KS_crit, mad_dict, digs_dict
+from numpy import errstate, log, sqrt, where
+from .constants import CRIT_CHI2, CRIT_KS, MAD_CONFORM, DIGS
 
 
 def Z_score(frame, N):
@@ -41,7 +41,7 @@ def chi_sq(frame, ddf, confidence, verbose=True):
         exp_counts = frame.Counts.sum() * frame.Expected
         dif_counts = frame.Counts - exp_counts
         found_chi = (dif_counts ** 2 / exp_counts).sum()
-        crit_chi = crit_chi2[ddf][confidence]
+        crit_chi = CRIT_CHI2[ddf][confidence]
         if verbose:
             print(f"\nThe Chi-square statistic is {found_chi:.4f}.\n"
                   f"Critical Chi-square for this series: {crit_chi}.")
@@ -88,7 +88,7 @@ def kolmogorov_smirnov(frame, confidence, N, verbose=True):
         # finding the supremum - the largest cumul dist difference
         suprem = ((ks_frame.Found - ks_frame.Expected).abs()).max()
         # calculating the crittical value according to confidence
-        crit_KS = KS_crit[confidence] / sqrt(N)
+        crit_KS = CRIT_KS[confidence] / sqrt(N)
 
         if verbose:
             print(f"\nThe Kolmogorov-Smirnov statistic is {suprem:.4f}.\n"
@@ -132,11 +132,11 @@ def mad(frame, test, verbose=True):
         print(f"\nThe Mean Absolute Deviation is {mad}")
 
         if test != -2:
-            print(f"For the {mad_dict[digs_dict[test]]}:\n\
-            - 0.0000 to {mad_dict[test][0]}: Close Conformity\n\
-            - {mad_dict[test][0]} to {mad_dict[test][1]}: Acceptable Conformity\n\
-            - {mad_dict[test][1]} to {mad_dict[test][2]}: Marginally Acceptable Conformity\n\
-            - Above {mad_dict[test][2]}: Nonconformity")
+            print(f"For the {MAD_CONFORM[DIGS[test]]}:\n\
+            - 0.0000 to {MAD_CONFORM[test][0]}: Close Conformity\n\
+            - {MAD_CONFORM[test][0]} to {MAD_CONFORM[test][1]}: Acceptable Conformity\n\
+            - {MAD_CONFORM[test][1]} to {MAD_CONFORM[test][2]}: Marginally Acceptable Conformity\n\
+            - Above {MAD_CONFORM[test][2]}: Nonconformity")
         else:
             pass
     return mad
@@ -159,3 +159,55 @@ def mse(frame, verbose=True):
         print(f"\nMean Square Error = {mse}")
 
     return mse
+
+def _bhattacharyya_coefficient(dist_1, dist_2):
+    """Computes the Bhattacharyya Coeficient between two probability
+    distributions, to be letar used to compute the Bhattacharyya Distance
+
+    Args:
+        dist_1 (np.array): The newly gathered distribution, to be compared
+            with an older / established distribution.
+        dist_2 (np.array): The older/ establhished distribution with which
+            the new one will be compared. 
+    
+    Returns:
+        bhat_coef (float)
+    """
+    return sqrt(dist_1 * dist_2).sum()
+
+
+def _bhattacharyya_distance_(dist_1, dist_2):
+    """Computes the Bhattacharyya Dsitance between two probability
+    distributions
+
+    Args:
+        dist_1 (np.array): The newly gathered distribution, to be compared
+            with an older / established distribution.
+        dist_2 (np.array): The older/ establhished distribution with which
+            the new one will be compared. 
+    
+    Returns:
+        bhat_dist (float)
+    """
+    with errstate(divide='ignore'):
+        bhat_dist =  -log(_bhattacharyya_coefficient(dist_1, dist_2))
+    return bhat_dist
+
+
+def _kullback_leibler_divergence_(dist_1, dist_2):
+    """Computes the Kullback-Leibler Divergence between two probability
+    distributions.
+
+    Args:
+        dist_1 (np.array): The newly gathered distribution, to be compared
+            with an older / established distribution.
+        dist_2 (np.array): The older/ establhished distribution with which
+            the new one will be compared. 
+
+    Returns:
+        kulb_leib_diverg (float)        
+    """
+    # ignore divide by zero warning in np.where
+    with errstate(divide='ignore'):
+        kl_d = (log((dist_1 / dist_2), where=(dist_1 != 0)) * dist_1).sum()
+    return kl_d
